﻿using Android.App;
using Android.OS;
using System.Collections.Generic;
using System.Linq;
using ThinkGeo.MapSuite.AndroidEdition;
using ThinkGeo.MapSuite.Core;

namespace SnapLayer
{
    [Activity(Label = "SnapLayer", MainLauncher = true, Icon = "@drawable/icon")]
    public class MainActivity : Activity
    {
        private MapView androidMap;

        protected override void OnCreate(Bundle bundle)
        {
            base.OnCreate(bundle);
            SetContentView(Resource.Layout.Main);

            androidMap = FindViewById<MapView>(Resource.Id.androidmap);
            androidMap.MapUnit = GeographyUnit.DecimalDegree;
            androidMap.CurrentExtent = new RectangleShape(-97.7591, 30.3126, -97.7317, 30.2964);

            Feature polygon = new Feature("POLYGON((-97.7375464920044 30.3131045265198,-97.7332549575806 30.3107441825867,-97.7382331375122 30.3030194206238, -97.7427821640015 30.3052510185242, -97.7375464920044 30.3131045265198))");
            Feature line = new Feature("LINESTRING(-97.75063 30.30911,-97.75153 30.30774,-97.75235 30.30658, -97.75119 30.30589,-97.75188 30.30477,-97.75256 30.30366,-97.75162 30.30319)");
            SnapToLayerEditInteractiveOverlay snapToLayerEditInteractiveOverlay = new SnapToLayerEditInteractiveOverlay();

            //inMemoryFeatureLayer used to be snapped to.
            InMemoryFeatureLayer polygonInMemoryFeatureLayer = new InMemoryFeatureLayer();
            polygonInMemoryFeatureLayer.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle = AreaStyles.Park1;
            polygonInMemoryFeatureLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
            polygonInMemoryFeatureLayer.InternalFeatures.Add("Polygon", polygon);

            LayerOverlay inMemoryOverlay = new LayerOverlay();
            inMemoryOverlay.Layers.Add("InMemoryFeatureLayer", polygonInMemoryFeatureLayer);
            androidMap.Overlays.Add("InMemoryOverlay", inMemoryOverlay);

            snapToLayerEditInteractiveOverlay.EditShapesLayer.InternalFeatures.Add("MultiLine", line);

            //Sets the PointStyle for the non dragged control points.
            snapToLayerEditInteractiveOverlay.ControlPointStyle = new PointStyle(PointSymbolType.Circle, new GeoSolidBrush(GeoColor.StandardColors.PaleGoldenrod), new GeoPen(GeoColor.StandardColors.Black), 8);
            //Sets the PointStyle for the dragged control points.
            snapToLayerEditInteractiveOverlay.DraggedControlPointStyle = new PointStyle(PointSymbolType.Circle, new GeoSolidBrush(GeoColor.StandardColors.Red), new GeoPen(GeoColor.StandardColors.Orange, 2), 10);

            snapToLayerEditInteractiveOverlay.ToSnapInMemoryFeatureLayer = polygonInMemoryFeatureLayer;

            //Example using Screen (Pixel) coordinates for tolerance.
            snapToLayerEditInteractiveOverlay.ToleranceType = ToleranceCoordinates.Screen;
            snapToLayerEditInteractiveOverlay.Tolerance = 25;

            int index = GetInteractiveOverlayIndex(androidMap.InteractiveOverlays, androidMap.EditOverlay);
            androidMap.InteractiveOverlays.RemoveAt(index);
            androidMap.InteractiveOverlays.Insert(index, snapToLayerEditInteractiveOverlay);
            androidMap.EditOverlay = snapToLayerEditInteractiveOverlay;
            androidMap.EditOverlay.CalculateAllControlPoints();

            androidMap.Refresh();
        }

        private int GetInteractiveOverlayIndex(GeoCollection<InteractiveOverlay> overlays, InteractiveOverlay overlay)
        {
            for(int i = 0; i < overlays.Count; i++)
            {
                InteractiveOverlay item = overlays[i];
                if(item == overlay)
                {
                    return i;
                }
            }

            return -1;
        }
    }
}

